# Surge Synth Team Tuning Library

Micro-tuning format parsing and frequency finding as a header-only C++ library.

Full documentation, tests, cli tools, etc. at https://github.com/surge-synthesizer/tuning-library
